@@ -10,8 +10,8 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import { Command, flags } from '@oclif/command'
-import { cli } from 'cli-ux'
+import { Command, Flags } from '@oclif/core'
+import { ux } from '@oclif/core'
 import {CheCtlContext} from '../../context'
 import {
   CHE_NAMESPACE_FLAG,
@@ -41,8 +41,8 @@ import {newListr} from '../../utils/utls'
 export default class Delete extends Command {
   static description = `delete any ${EclipseChe.PRODUCT_NAME} related resource`
 
-  static flags: flags.Input<any> = {
-    help: flags.help({ char: 'h' }),
+  static flags = {
+    help: Flags.help({ char: 'h' }),
     [CHE_NAMESPACE_FLAG]: CHE_NAMESPACE,
     [DELETE_ALL_FLAG]: DELETE_ALL,
     [DELETE_NAMESPACE_FLAG]: DELETE_NAMESPACE,
@@ -54,7 +54,7 @@ export default class Delete extends Command {
   }
 
   async run() {
-    const { flags } = this.parse(Delete)
+    const { flags } = await this.parse(Delete)
     const ctx = await CheCtlContext.initAndGet(flags, this)
 
     await this.config.runHook(DEFAULT_ANALYTIC_HOOK_NAME, { command: Delete.id, flags })
@@ -66,13 +66,13 @@ export default class Delete extends Command {
     tasks.add(CheTasks.getWaitPodsDeletedTasks())
 
     if (flags[DELETE_NAMESPACE_FLAG]) {
-      tasks.add(CommonTasks.getDeleteNamespaceTask(flags[CHE_NAMESPACE_FLAG]))
+      tasks.add(CommonTasks.getDeleteNamespaceTask(flags[CHE_NAMESPACE_FLAG]!))
     }
 
     if (await this.isDeletionConfirmed(flags)) {
       try {
         await tasks.run(ctx)
-        cli.log(getCommandSuccessMessage())
+        ux.log(getCommandSuccessMessage())
       } catch (err: any) {
         this.error(wrapCommandError(err))
       }
@@ -83,6 +83,7 @@ export default class Delete extends Command {
     if (!flags[BATCH_FLAG]) {
       notifyCommandCompletedSuccessfully()
     }
+
     this.exit(0)
   }
 
@@ -96,7 +97,7 @@ export default class Delete extends Command {
     }
 
     if (!flags[BATCH_FLAG] && !flags[ASSUME_YES_FLAG]) {
-      return cli.confirm(`You're going to remove ${EclipseChe.PRODUCT_NAME} server in namespace '${flags[CHE_NAMESPACE_FLAG]}' on server '${cluster ? cluster.server : ''}'. If you want to continue - press Y`)
+      return ux.confirm(`You're going to remove ${EclipseChe.PRODUCT_NAME} server in namespace '${flags[CHE_NAMESPACE_FLAG]}' on server '${cluster ? cluster.server : ''}'. If you want to continue - press Y`)
     }
 
     return true
