@@ -80,9 +80,9 @@ export namespace DevWorkspace {
   export const SUBSCRIPTION = 'devworkspace-operator'
   export const PACKAGE = 'devworkspace-operator'
   export const NEXT_CHANNEL_CATALOG_SOURCE = 'devworkspace-operator'
-  export const NEXT_CHANNEL = 'next'
+  export const NEXT_CHANNEL = 'fast'
   export const NEXT_CHANNEL_CATALOG_SOURCE_IMAGE = 'quay.io/devfile/devworkspace-operator-index:next'
-  export const STABLE_CHANNEL_CATALOG_SOURCE = 'devworkspace-operator'
+  export const STABLE_CHANNEL_CATALOG_SOURCE = 'redhat-operators'
   export const STABLE_CHANNEL = 'fast'
   export const STABLE_CHANNEL_CATALOG_SOURCE_IMAGE = 'quay.io/devfile/devworkspace-operator-index:release'
 }
