@@ -84,7 +84,15 @@ export namespace MinikubeTasks {
           const args: string[] = []
           args.push('ssh', 'sudo mkdir -p /etc/ca-certificates')
 
-          await execa('minikube', args, { timeout: 60_000 })
+          const { stderr, exitCode } = await execa('minikube', args, { timeout: 60_000, reject: false })
+
+          // Check the error code and driver and if it is 14(MK_USAGE) and `none`, ignore the exception
+          // if not MK_USAGE(errorCode: 14) when throw Error.
+          // if MK_USAGE and not include `'none' driver` when throw Error.
+          const EXIT_CODE_MK_USAGE: number = 14
+          if (exitCode && (exitCode !== EXIT_CODE_MK_USAGE || !stderr.includes('\'none\' driver'))) {
+            throw new Error(`Failed to create /etc/ca-certificates directory: ${stderr}`)
+          }
 
           task.title = `${task.title}...[Created]`
         },
