@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2019-2022 Red Hat, Inc.
+ * Copyright (c) 2019-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -134,11 +134,4 @@ export namespace Che {
 
     throw new Error(`Route ${EclipseChe.CHE_FLAVOR} not found`)
   }
-
-  export async function isEmbeddedOpenVSXRegistryConfigured(namespace: string): Promise<boolean> {
-    const kubeClient = KubeClient.getInstance()
-    const cheCluster = await kubeClient.getCheCluster(namespace)
-
-    return !cheCluster?.spec?.components?.pluginRegistry?.openVSXURL
-  }
 }
