@@ -33,7 +33,7 @@ const A_DAY_IN_MS = 24 * 60 * 60 * 1000
 export namespace CheCtlVersion {
 
   /**
-   * Returns latest chectl version for the given channel.
+   * Returns latest dsc version for the given channel.
    */
   export async function getLatestCheCtlVersion(channel: string): Promise<string | undefined> {
     if (!CheCtlContext.get()[CliContext.CLI_IS_CHECTL]) {
@@ -45,7 +45,7 @@ export namespace CheCtlVersion {
     })
 
     try {
-      const { data } = await axiosInstance.get(`https://che-incubator.github.io/chectl/channels/${channel}/linux-x64`)
+      const { data } = await axiosInstance.get(`https://che-incubator.github.io/dsc/channels/${channel}/linux-x64`)
       return data.version
     } catch {
       return
@@ -53,19 +53,19 @@ export namespace CheCtlVersion {
   }
 
   /**
-   * Checks whether there is an update available for current chectl.
+   * Checks whether there is an update available for current dsc.
    */
   export async function isCheCtlUpdateAvailable(cacheDir: string, forceRecheck = false): Promise<boolean> {
     // Do not use ctx inside this function as the function is used from hook where ctx is not yet defined.
 
     if (!CheCtlContext.get()[CliContext.CLI_IS_CHECTL]) {
-      // Do nothing for not chectl flavors
+      // Do nothing for not dsc flavors
       return false
     }
 
     const currentVersion = getProjectVersion()
     if (currentVersion === CHECTL_DEVELOPMENT_VERSION) {
-      // Skip it, chectl is built from source
+      // Skip it, dsc is built from source
       return false
     }
 
