@@ -52,6 +52,9 @@ pushd "${SOURCEDIR}" >/dev/null
   done <   <(find src test resources configs package.json .ci/obfuscate/gnirts.js .eslintrc.js -type f -name "*" -print0) # include package.json in here too
 popd >/dev/null
 
+# Remove dex, only needed for upstream
+rm -rf ${TARGETDIR}/resources/dex
+
 # Productization
 pushd "${TARGETDIR}" >/dev/null
   d=src/tasks/installers/eclipse-che/eclipse-che.ts
@@ -160,15 +163,13 @@ replaceFile="${TARGETDIR}/package.json"
 if [[ -f ${replaceFile} ]]; then
   echo "[INFO] Convert package.json (sed)"
   sed -i ${replaceFile} -r \
-  -e 's#Eclipse Che#Red Hat OpenShift Dev Spaces#g' \
-  -e 's#"devworkspace-operator":#"//":#g'
+  -e 's#Eclipse Che#Red Hat OpenShift Dev Spaces#g'
 
   echo "[INFO] Convert package.json (jq)"
   declare -A package_replacements=(
-    ["file:/che-operator"]='.dependencies["eclipse-che-operator"]'
     ["dsc"]='.name'
     ["Red Hat OpenShift Dev Spaces CLI"]='.description'
-    ["${DS_VERSION}.0-CI"]='.version'
+    ["${DS_VERSION}.0"]='.version'
     ["./bin/run"]='.bin["dsc"]'
     ["https://issues.jboss.org/projects/CRW/issues"]='.bugs'
     ["https://developers.redhat.com/products/openshift-dev-spaces"]='.homepage'
@@ -180,4 +181,17 @@ if [[ -f ${replaceFile} ]]; then
     updateName="${package_replacements[$updateVal]}"
     replaceVar
   done
+
+  # Removes dependencies not needed for downstream
+  jq 'del(.dependencies."eclipse-che-operator")' ${TARGETDIR}/package.json  > ${TARGETDIR}/package.json.tmp && mv ${TARGETDIR}/package.json.tmp ${TARGETDIR}/package.json
+  jq 'del(.dependencies."devworkspace-operator")' ${TARGETDIR}/package.json  > ${TARGETDIR}/package.json.tmp && mv ${TARGETDIR}/package.json.tmp ${TARGETDIR}/package.json
+  jq 'del(.scripts."postinstall-operator")' ${TARGETDIR}/package.json  > ${TARGETDIR}/package.json.tmp && mv ${TARGETDIR}/package.json.tmp ${TARGETDIR}/package.json
+  jq '.files |= map(select(. != "/prepare-templates.js"))' ${TARGETDIR}/package.json  > ${TARGETDIR}/package.json.tmp && mv ${TARGETDIR}/package.json.tmp ${TARGETDIR}/package.json
+  sed -i 's#npm run -s postinstall-operator &&##g' ${TARGETDIR}/package.json
+
+  # only used for deploying on k8sz
+  sed -i "s#ctx\[EclipseCheContext.DEFAULT_CR\] =.*#ctx[EclipseCheContext.DEFAULT_CR] = ''#g" ${TARGETDIR}/src/context.ts
+
+  # dsc update not possible for downstream
+  jq '.oclif.plugins |= map(select(. != "@oclif/plugin-update"))' ${TARGETDIR}/package.json  > ${TARGETDIR}/package.json.tmp && mv ${TARGETDIR}/package.json.tmp ${TARGETDIR}/package.json
 fi
