@@ -24,9 +24,9 @@ const CHE_VERSION_TIMEOUT_MS = 10 * 60 * 1000
 describe('Test Che upgrade', () => {
   describe('Prepare latest stable Che', () => {
     it(`Deploy Che using operator installer and self signed certificates`, async () => {
-      // uses installed chectl (from a stable channel)
+      // uses installed dsc (from a stable channel)
       // see github workflow
-      let deployCommand = `chectl server:deploy --batch --platform=${PLATFORM} --chenamespace=${NAMESPACE} --telemetry=off --k8spodwaittimeout=600000 --k8spodreadytimeout=600000`
+      let deployCommand = `dsc server:deploy --batch --platform=${PLATFORM} --chenamespace=${NAMESPACE} --telemetry=off --k8spodwaittimeout=600000 --k8spodreadytimeout=600000`
       if (PLATFORM === 'minikube') {
         deployCommand += ' --che-operator-cr-patch-yaml=test/e2e/resources/minikube-checluster-patch.yaml'
       }
